RiskLab Report

## Decision Confidence

--%
Confidence
Tail Amplification Ratio
--
vs Benchmark CVaR (Lower is better, <1.0 is superior)

## Fragility Gauge

--
Parameter Sensitivity (0-100)

## Regime Dependence Map

Bull / Low Vol --
Bull / High Vol --
Bear / Low Vol --
Bear / High Vol --
Sharpe Ratio per Regime

### Scenario Stress Test

## Detailed Scenario Results

Scenario | Robustness Score | Max Drawdown | Sharpe Ratio
--- | --- | --- | ---